@@ -76,7 +76,7 @@ class Time(MapBefore, Equals[time], AfterBefore[time], Predicate):
 
 
 @dataclass
-class AnyDateTime(
+class DateOrTime(
     MapBefore, Equals[typing.Union[datetime, date, time, timedelta]], Instance, Predicate
 ):
     # after / before is a bit more complicated in this case
@@ -160,29 +160,37 @@ def parse_isoformat(dt):
     raise ValueError("Only str is allowed")
 
 
+ANY_DATETIME = DateTime()
+ANY_DATE = Date()
+ANY_TIME = Time()
+
+ANY_DATETIME_ISO = DateTime(map_before=parse_isoformat)
+ANY_DATE_ISO = Date(map_before=parse_isoformat)
+ANY_TIME_ISO = Time(map_before=parse_isoformat)
+
 # before=timedelta(microseconds=1) to allow current time
-LAST_SECOND = AnyDateTime(after=timedelta(seconds=-1), before=timedelta(microseconds=1))
-LAST_MINUTE = AnyDateTime(after=timedelta(minutes=-1), before=timedelta(microseconds=1))
-LAST_HOUR = AnyDateTime(after=timedelta(hours=-1), before=timedelta(microseconds=1))
-LAST_DAY = AnyDateTime(after=timedelta(days=-1), before=timedelta(microseconds=1))
-LAST_WEEK = AnyDateTime(after=timedelta(weeks=-1), before=timedelta(microseconds=1))
-LAST_YEAR = AnyDateTime(after=timedelta(days=-365), before=timedelta(microseconds=1))
-LAST_SECOND_ISO = AnyDateTime(
+LAST_SECOND = DateOrTime(after=timedelta(seconds=-1), before=timedelta(microseconds=1))
+LAST_MINUTE = DateOrTime(after=timedelta(minutes=-1), before=timedelta(microseconds=1))
+LAST_HOUR = DateOrTime(after=timedelta(hours=-1), before=timedelta(microseconds=1))
+LAST_DAY = DateOrTime(after=timedelta(days=-1), before=timedelta(microseconds=1))
+LAST_WEEK = DateOrTime(after=timedelta(weeks=-1), before=timedelta(microseconds=1))
+LAST_YEAR = DateOrTime(after=timedelta(days=-365), before=timedelta(microseconds=1))
+LAST_SECOND_ISO = DateOrTime(
     after=timedelta(seconds=-1), before=timedelta(microseconds=1), map_before=parse_isoformat
 )
-LAST_MINUTE_ISO = AnyDateTime(
+LAST_MINUTE_ISO = DateOrTime(
     after=timedelta(minutes=-1), before=timedelta(microseconds=1), map_before=parse_isoformat
 )
-LAST_HOUR_ISO = AnyDateTime(
+LAST_HOUR_ISO = DateOrTime(
     after=timedelta(hours=-1), before=timedelta(microseconds=1), map_before=parse_isoformat
 )
-LAST_DAY_ISO = AnyDateTime(
+LAST_DAY_ISO = DateOrTime(
     after=timedelta(days=-1), before=timedelta(microseconds=1), map_before=parse_isoformat
 )
-LAST_WEEK_ISO = AnyDateTime(
+LAST_WEEK_ISO = DateOrTime(
     after=timedelta(weeks=-1), before=timedelta(microseconds=1), map_before=parse_isoformat
 )
-LAST_YEAR_ISO = AnyDateTime(
+LAST_YEAR_ISO = DateOrTime(
     after=timedelta(days=-365), before=timedelta(microseconds=1), map_before=parse_isoformat
 )
 
@@ -190,7 +198,7 @@ LAST_YEAR_ISO = AnyDateTime(
 # TODO:
 # THIS_MINUTE
 # THIS_HOUR
-THIS_DAY = AnyDateTime(
+THIS_DAY = DateOrTime(
     after=date.today() - timedelta(days=1),
     before=date.today() + timedelta(days=1),
 )
@@ -200,7 +208,7 @@ TODAY = THIS_DAY
 # THIS_MONTH
 # THIS_YEAR
 
-THIS_DAY_ISO = AnyDateTime(
+THIS_DAY_ISO = DateOrTime(
     after=date.today() - timedelta(days=1),
     before=date.today() + timedelta(days=1),
     map_before=parse_isoformat,
