@@ -44,6 +44,6 @@ class String(MapBefore, Equals[str], Instance, Length, Contains, Predicate):
         return flags
 
 
-UUID = String(
+ANY_UUID = String(
     regex=re.compile("[a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89aAbB][a-f0-9]{3}-[a-f0-9]{12}")
 )
